import { useState } from "react";
import Slider from "rc-slider";
import "rc-slider/assets/index.css";
import "../stylesheets/FilterPage.css";
import DropDownFilter from "./DropDownFilter";
import { PropsSliderFilter } from "../utils/commonTypes";
import {
  GroundType,
  GroundTypeTranslated,
  LightingDemand,
  LightingDemandTranslated,
  NutrientDemand,
  NutrientDemandTranslated,
  WaterDemand,
  WaterDemandTranslated,
  translateGroundTypeReverse,
  translateLightingDemandReverse,
  translateNutrientDemandReverse,
  translateWaterDemandReverse,
} from "../utils/schemas";

type FilterPageProps = {
  setWaterDemand: (value: WaterDemand) => void;
  setNutrientDemand: (value: NutrientDemand) => void;
  setLightingDemand: (value: LightingDemand) => void;
  setGroundType: (value: GroundType) => void;
  setPlantDuration: (value: [number, number]) => void;
  setGrowthDuration: (value: [number, number]) => void;
};

function FilterPage({
  setGroundType,
  setGrowthDuration,
  setLightingDemand,
  setNutrientDemand,
  setPlantDuration,
  setWaterDemand,
}: FilterPageProps) {
  const handleGroundType = (groundType: GroundTypeTranslated) => {
    setGroundType(translateGroundTypeReverse(groundType));
  };
  const handleWaterDemand = (waterDemand: WaterDemandTranslated) => {
    setWaterDemand(translateWaterDemandReverse(waterDemand));
  };
  const handleNutrientDemand = (nutrientDemand: NutrientDemandTranslated) => {
    setNutrientDemand(translateNutrientDemandReverse(nutrientDemand));
  };
  const handleLightingDemand = (lightingDemand: LightingDemandTranslated) => {
    setLightingDemand(translateLightingDemandReverse(lightingDemand));
  };
  return (
    <>
      <div className="filterPage">
        <h3>Setze Filter und suche nach passenden Pflanzen</h3>
      </div>
      <div>
        <DropDownFilter
          topic={"Wasserbedarf "}
          options={["Trocken", "Feucht", "Sehr feucht"]}
          filterOnChange={handleWaterDemand}
        />
        <DropDownFilter
          topic={"Nährstoffbedarf "}
          options={["Niedrig", "Mittel", "Hoch"]}
          filterOnChange={handleNutrientDemand}
        />
        <DropDownFilter
          topic={"Lichtbedarf "}
          options={["Niedrig", "Mittel", "Hoch"]}
          filterOnChange={handleLightingDemand}
        />
        <DropDownFilter
          topic={"Bodentyp"}
          options={["Leicht", "Mittel", "Schwer"]}
          filterOnChange={handleGroundType}
        />
      </div>
      <SliderFilter
        topic={"Anbauphase"}
        min={1}
        max={52}
        filterOnChange={setPlantDuration}
      />
      <SliderFilter
        topic={"Wachstumsdauer"}
        min={1}
        max={52}
        filterOnChange={setGrowthDuration}
      />{" "}
    </>
  );
}

function SliderFilter({ topic, min, max, filterOnChange }: PropsSliderFilter) {
  const [range, setRange] = useState([min, max]);

  const handleRangeChange = (newRange: any) => {
    setRange(newRange);
    filterOnChange!(newRange);
  };

  return (
    <div>
      <label>
        {topic} von KW {range[0]} bis KW {range[1]}
      </label>
      <Slider
        min={min}
        max={max}
        range
        value={range}
        onChange={handleRangeChange}
      />
    </div>
  );
}

export default FilterPage;
