package hdm.mi.growbros.service;

import hdm.mi.growbros.models.WishListEntry;
import hdm.mi.growbros.models.plant.Plant;
import hdm.mi.growbros.models.user.User;
import hdm.mi.growbros.repositories.WishListRepository;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.temporal.WeekFields;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Random;

@Service

public class GrandmaService {


    private final WishListRepository wishListRepository;



    private final GardenService gardenService;


    public GrandmaService(WishListRepository wishListRepository , GardenService gardenService) {

        this.wishListRepository = wishListRepository;
        this.gardenService = gardenService;
    }


    public String growingTippDesTages(User user) {
        List<Plant> usersPlants = gardenService.getUserPlants(user , null);
        String tipDesTages;
        Random random = new Random();
        int randomNumber = random.nextInt(usersPlants.size());
        tipDesTages = "Tip des Tages für deinen Garten" + usersPlants.get(randomNumber).getGrowingTips();
        return tipDesTages;
    }


    public String notifyAboutPlantsReadyToGrow(User user){
            List<Plant> plantsReadyToGrow = getPlantsReadyToGrow(user);
            if (plantsReadyToGrow.isEmpty()) {
                return "";
            }
            StringBuilder notification = new StringBuilder("Diese Pflanzen in deiner Wunschliste wären bereit zum Einpflanzen: ");
            int size = plantsReadyToGrow.size();
            for (int i = 0; i < size; i++) {
                notification.append(plantsReadyToGrow.get(i).getName());
                if (i < size - 2) {
                    notification.append(", ");
                } else if (i == size - 2) {
                    notification.append(" und ");
                }
            }
            return notification.toString();
        }


    private List<Plant> getPlantsReadyToGrow( User user) {
        LocalDate today = LocalDate.now();

        int weekNumber = today.get(WeekFields.of(Locale.getDefault()).weekOfWeekBasedYear());

        List<Plant> plantsReadyToGrow = new ArrayList<>();

        List<WishListEntry> wishListEntries = wishListRepository.findByCurrentPlantingWeek(user, weekNumber);

        for (WishListEntry entry : wishListEntries) {

            plantsReadyToGrow.add(entry.getPlant());

        }

        return plantsReadyToGrow;
    }
}
